@@ -1,6 +1,7 @@
 import logging
 import sys
 import warnings
+import json
 from sqlalchemy.engine import create_engine
 from sqlalchemy import MetaData
 from sqlalchemy import Table
@@ -132,6 +133,82 @@ quotes_dict = {
     "exasol": '"',
 }
 
+max_length_mult = {
+    "ch": 1,
+    "pg": 1,
+    "mysql": 1,
+    "vertica": 1.8,
+    "exasol": 1,
+}
+
+# types update to insert then
+update_types_dict = {
+    "ch": {"int32": "int", "int8": "bool", "str": "str", "float": "float"},
+    "pg": {
+        "double precision": "float",
+        "integer": "int",
+        "json": "json",
+        "boolean": "bool",
+    },
+    "mysql": {
+        "double precision": "float",
+        "int": "int",
+        "json": "json",
+        "boolean": "bool",
+    },
+    "vertica": {
+        "double precision": "float",
+        "integer": "int",
+        "json": "json",
+        "boolean": "bool",
+    },
+    "exasol": {
+        "double precision": "float",
+        "integer": "int",
+        "json": "json",
+        "boolean": "bool",
+    },
+}
+
+
+def update_value_type(fields, item, key, db="ch"):
+    """
+    :param db: db to update
+    :param fields: dict - key  type
+    :param item: - to upldate item
+    :param key: key to updatee
+    :return:
+    """
+    if db not in dialect_dict:
+        raise ModuleNotFoundError(
+            "Dialect for {} type of database was'nt found, should be in list {}".format(
+                db, list(dialect_dict.keys())
+            )
+        )
+    if item is None:
+        return item
+    if item[key] is None:
+        return item
+    type = "str"
+    for type_old in update_types_dict[db]:
+        if fields[key].lower().find(type_old) > -1:
+            type = update_types_dict[db][type_old]
+
+    if type == "int":
+        item[key] = int(item[key])
+    elif type == "float":
+        item[key] = float(item[key])
+    elif type == "json":
+        item[key] = json.dumps(item[key])
+    elif type == "bool":
+        item[key] = bool(item[key])
+    else:
+        item[key] = str(item[key])
+    return item
+
+
+excluded_fields = ["password"]
+
 
 def update_column_type(column, from_db, to_db):
     """convert types between source and destination"""
@@ -150,7 +227,9 @@ def update_column_type(column, from_db, to_db):
 
     if column["character_maximum_length"] is not None and type_to not in "text":
         type_to += "({character_maximum_length})".format(
-            character_maximum_length=column["character_maximum_length"]
+            character_maximum_length=int(
+                column["character_maximum_length"] * max_length_mult[to_db]
+            )
         )
         return type_to
     if column["column_default"] is not None:
@@ -215,6 +294,105 @@ def get_table_schema(table_name, meta):
     return fields
 
 
+class FieldsConverterOneWay:
+    """
+    class to upload just one way
+    """
+
+    def __init__(self, sql_credentials, db, debug=True, tables=None):
+        """
+
+        :param sql_credentials:
+        :param db:
+        :param debug: show debug text
+        :param tables:  converter only for list of tables. Will process more rapid
+        """
+        self.tables = tables or []
+        self.db = db
+        self.debug = debug
+        self.sql_credentials = sql_credentials
+        cred = self.sql_credentials[self.db]
+
+        if self.db not in dialect_dict:
+            raise ModuleNotFoundError(
+                "Dialect for {} type of database was'nt found, should be in list {}".format(
+                    self.db, list(dialect_dict.keys())
+                )
+            )
+        else:
+            dialect_from = dialect_dict[self.db]
+        uri_sql_alchemy = "{0}://{1}:{2}@{3}:{4}/{5}".format(
+            dialect_from,
+            cred["user"],
+            cred["password"],
+            cred["host"],
+            cred["port"],
+            cred["database"],
+        )
+
+        engine = create_engine(uri_sql_alchemy)
+        self.conn = engine.connect()
+        self.log("connecting to {} successfull".format(self.db))
+        if "schema" in cred:
+            self.schema = cred["schema"]
+            self.meta = MetaData(bind=engine, schema=self.schema)
+        else:
+            self.meta = MetaData(bind=engine)
+
+        if len(self.tables) > 0:
+            self.meta.reflect(only=self.tables)
+        else:
+            self.meta.reflect()
+
+    def log(self, text):
+        if self.debug:
+            logging.info(self.__str__ + ": " + text)
+
+    def check_if_table_availible(self, table):
+        if len(self.tables) > 0 and table not in self.tables:
+            raise ModuleNotFoundError(
+                "Table_name to convert {} should be in list{} or set tables param to defult".format(
+                    table, self.tables
+                )
+            )
+
+    @property
+    def __str__(self):
+        return "FieldsConverterOneWay_{}".format(self.db)
+
+    @property
+    def __repr__(self):
+        return "FieldsConverterOneWay_{}".format(self.db)
+
+    def __del__(self):
+        self.conn.close()
+
+    def update_value_type(self, table_name, items):
+        """
+        :param items: list of dicts to update
+        :param table_name: table_name to insert
+        :return:
+        """
+        fields = self.get_columns(table_name=table_name)
+        keys = fields.keys()
+        for item in items:
+            for key in keys:
+                item = update_value_type(fields, item, key, db=self.db)
+        return items
+
+    def get_columns(self, table_name):
+        """get column:type dict"""
+        self.check_if_table_availible(table_name)
+        fields = get_table_schema(table_name, self.meta)
+        columns = [
+            f["column_name"] for f in fields if f["column_name"] not in excluded_fields
+        ]
+        types = [
+            f["data_type"] for f in fields if f["column_name"] not in excluded_fields
+        ]
+        return dict(zip(columns, types))
+
+
 class FieldsConverter:
     def __init__(self, sql_credentials, from_db, to_db, debug=True, tables=None):
         """
@@ -294,7 +472,6 @@ class FieldsConverter:
             self.meta_from.reflect()
             self.meta_to.reflect()
 
-
     def log(self, text):
         if self.debug:
             logging.info(self.__str__ + ": " + text)
@@ -319,6 +496,19 @@ class FieldsConverter:
         self.conn_from.close()
         self.conn_to.close()
 
+    def update_value_type(self, table_name, items):
+        """
+        :param items: list of dicts to update
+        :param table_name: table_name to insert
+        :return:
+        """
+        fields = self.get_columns(table_name=table_name, table_from=False)
+        keys = fields.keys()
+        for item in items:
+            for key in keys:
+                item = update_value_type(fields, item, key, db=self.to_db)
+        return items
+
     def generate_create(self, fields, table_name, sort_part=None):
         add_part = ""
         if self.schema_to:
@@ -333,8 +523,8 @@ class FieldsConverter:
             if sort_part is not None:
                 add_part = generate_sort_part_vertica(sort_part, date_field=date_field)
                 if (
-                        date_field != ""
-                        and fields[date_field].lower().find("not null") == -1
+                    date_field != ""
+                    and fields[date_field].lower().find("not null") == -1
                 ):
                     fields[date_field] += " not null"
         elif self.to_db == "exasol":
@@ -347,7 +537,7 @@ class FieldsConverter:
             [
                 self.quote_char + field + self.quote_char + " " + str(fields[field])
                 for field in fields
-                if field != "password"
+                if field not in excluded_fields
             ]
         )
         txt += ")"
@@ -365,7 +555,7 @@ class FieldsConverter:
               """.format(
             table_name=table_name, database=self.ch_database
         )
-        rows = self.ch_client.execute(sql)
+        rows = self.conn_from.execute(sql)
         if rows[0][2] == "MaterializedView":
             return self.get_partition_and_sort_keys_ch(".inner." + table_name)
         else:
@@ -378,8 +568,12 @@ class FieldsConverter:
             fields = get_table_schema(table_name, self.meta_from)
         else:
             fields = get_table_schema(table_name, self.meta_to)
-        columns = [f["column_name"] for f in fields]
-        types = [f["data_type"] for f in fields]
+        columns = [
+            f["column_name"] for f in fields if f["column_name"] not in excluded_fields
+        ]
+        types = [
+            f["data_type"] for f in fields if f["column_name"] not in excluded_fields
+        ]
         return dict(zip(columns, types))
 
     def create_ddl(self, table_name):
